<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://cedcommerce.com
 * @since      1.0.0
 *
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/includes
 */
class Shopify_Connector_For_Woocommerce {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @var      Shopify_Connector_For_Woocommerce_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'SHOPIFY_CONNECTOR_FOR_WOOCOMMERCE_VERSION' ) ) {
			$this->version = SHOPIFY_CONNECTOR_FOR_WOOCOMMERCE_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'shopify-connector-for-woocommerce';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->load_constants();
	}
	/**
	 * Load the constansts for the plugin.
	 *
	 * @since    1.0.0
	 */
	public function load_constants() {
		define( 'CED_SCW_PATH', plugin_dir_path( dirname( __FILE__ ) ) );
		define( 'CED_SCW_URL', plugin_dir_url( dirname( __FILE__ ) ) );
		define( 'CED_SCW_PREFIX', 'ced_scw_' );
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Shopify_Connector_For_Woocommerce_Loader. Orchestrates the hooks of the plugin.
	 * - Shopify_Connector_For_Woocommerce_I18n. Defines internationalization functionality.
	 * - Shopify_Connector_For_Woocommerce_Admin. Defines all hooks for the admin area.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-shopify-connector-for-woocommerce-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-shopify-connector-for-woocommerce-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-shopify-connector-for-woocommerce-admin.php';

		$this->loader = new Shopify_Connector_For_Woocommerce_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Shopify_Connector_For_Woocommerce_I18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 */
	private function set_locale() {
		$plugin_i18n = new Shopify_Connector_For_Woocommerce_I18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 */
	private function define_admin_hooks() {
		$plugin_admin = new Shopify_Connector_For_Woocommerce_Admin( $this->get_plugin_name(), $this->get_version() );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		$this->loader->add_action( 'admin_menu', $plugin_admin, 'ced_scw_add_menus', 1 );
		$this->loader->add_filter( 'ced_add_marketplace_menus_array', $plugin_admin, 'ced_scw_add_marketplace_menus_to_array', 13 );
		$this->loader->add_filter( 'ced_scw_add_saas_marketplace_array', $plugin_admin, 'ced_scw_add_saas_marketplace_to_array', 13 );
		$this->loader->add_filter( 'wp_ajax_ced_scw_save_API_details_and_verify', $plugin_admin, 'ced_scw_save_API_details_and_verify' );
		$this->loader->add_filter( 'wp_ajax_ced_scw_reset_API_details', $plugin_admin, 'ced_scw_reset_API_details' );

		$this->loader->add_action( 'wp_ajax_ced_scw_validate_token', $plugin_admin, 'ced_scw_validate_token' );
		$this->loader->add_action( 'wp_ajax_ced_scw_fetch_shopify_stored_collection', $plugin_admin, 'ced_scw_fetch_shopify_stored_collection' );
		$this->loader->add_action( 'wp_ajax_ced_scw_fetch_shopify_collection_recursive', $plugin_admin, 'ced_scw_fetch_shopify_collection_recursive' );
		$this->loader->add_action( 'wp_ajax_ced_scw_selected_import_option', $plugin_admin, 'ced_scw_selected_import_option' );
		$this->loader->add_action( 'wp_ajax_ced_scw_search_collection_in_category_array', $plugin_admin, 'ced_scw_search_collection_in_category_array' );
		$this->loader->add_action( 'wp_ajax_ced_scw_collection_setting_meta', $plugin_admin, 'ced_scw_collection_setting_meta' );

		$this->loader->add_action( 'wp_ajax_ced_scw_fetch_steps_shopify', $plugin_admin, 'ced_scw_fetch_steps_shopify' );
		$this->loader->add_action( 'wp_ajax_ced_scw_fetch_log_file_path_shopify', $plugin_admin, 'ced_scw_fetch_log_file_path_shopify' );
		$this->loader->add_action( 'wp_ajax_ced_scw_fetch_product_data_shopify', $plugin_admin, 'ced_scw_fetch_product_data_shopify' );
		$this->loader->add_action( 'wp_ajax_ced_shopify_prepare_product_ids_to_import', $plugin_admin, 'ced_shopify_prepare_product_ids_to_import' );
		$this->loader->add_action( 'wp_ajax_ced_shopify_fetch_customers_data', $plugin_admin, 'ced_shopify_fetch_customers_data' );
		$this->loader->add_action( 'wp_ajax_ced_shopify_fetch_orders', $plugin_admin, 'ced_shopify_fetch_orders' );
		$this->loader->add_action( 'wp_ajax_ced_scw_pricing_plan_selection', $plugin_admin, 'ced_scw_pricing_plan_selection' );
		$this->loader->add_action( 'wp_ajax_ced_scw_pricing_plan_cancellation', $plugin_admin, 'ced_scw_pricing_plan_cancellation' );
		$this->loader->add_action( 'wp_ajax_ced_scw_fetch_locations', $plugin_admin, 'ced_scw_fetch_locations' );
		$this->loader->add_action( 'wp_ajax_ced_scw_save_selected_location', $plugin_admin, 'ced_scw_save_selected_location' );
		$this->loader->add_action( 'woocommerce_order_status_processing', $plugin_admin, 'ced_scw_update_inventory_on_shopify', 10, 2 );
		$this->loader->add_filter( 'cron_schedules', $plugin_admin, 'ced_scw_cronSchedules', 1, 1 );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'ced_scw_set_schedules' );
		$this->loader->add_action( 'ced_scw_auto_sync_existing_products', $plugin_admin, 'ced_scw_auto_sync_from_shopify' );
		$this->loader->add_action( 'manage_edit-product_columns', $plugin_admin, 'ced_swc_add_table_columns' );
		$this->loader->add_action( 'manage_product_posts_custom_column', $plugin_admin, 'ced_swc_manage_table_columns', 10, 2 );
		$this->loader->add_action( 'wp_ajax_ced_swc_instant_sync_using_action', $plugin_admin, 'ced_swc_instant_sync_using_action' );
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Shopify_Connector_For_Woocommerce_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
